@@ -39,7 +39,10 @@ fn main() {
     debug!("transformed functions: {:?}", &api_file);
 
     info!("Phase: Generate Rust code");
-    let generated_rust = generator_rust::generate(&api_file, &path_stem(&config.rust_input_path));
+    let generated_rust = generator_rust::generate(
+        &api_file,
+        &mod_from_rust_path(&config.rust_input_path, &config.rust_crate_dir),
+    );
     fs::write(&config.rust_output_path, generated_rust.code).unwrap();
 
     info!("Phase: Generate Dart code");
@@ -54,10 +57,12 @@ fn main() {
 
     commands::format_rust(&config.rust_output_path);
 
-    others::try_add_mod_to_lib(&config.rust_crate_dir, &config.rust_output_path);
+    if !config.skip_add_mod_to_lib {
+        others::try_add_mod_to_lib(&config.rust_crate_dir, &config.rust_output_path);
+    }
 
     let c_struct_names = api_file
-        .distinct_types()
+        .distinct_types(true, true)
         .iter()
         .filter_map(|ty| {
             if let ApiType::StructRef(_) = ty {
@@ -84,6 +89,7 @@ fn main() {
                 temp_dart_wire_file.path().as_os_str().to_str().unwrap(),
                 &config.dart_wire_class_name(),
                 c_struct_names,
+                &config.llvm_path,
             );
         },
     );
